#!/usr/bin/env python

from distutils.core import setup

setup(name='fresh-canvas',
      version='0.1.2',
      py_modules=['fresh-canvas'],
      description='Fresh Canvas | The Project Base',
      author='Tushar Iyer',
      author_email='redacted@email.site',
      url='https://github.com/tushariyer/canvas',
      )
